pub struct AnalyzerSettings {Show 16 fields
pub analysis_type: AnalysisType,
pub exif_date_type: ExifDateType,
pub source_dirs: Vec<PathBuf>,
pub target_dir: PathBuf,
pub recursive_source: bool,
pub file_format: String,
pub nodate_file_format: String,
pub unknown_file_format: Option<String>,
pub bracketed_file_format: Option<String>,
pub date_format: String,
pub bracketing_formatting: BracketingFormattingPriority,
pub extensions: Vec<String>,
pub action_type: ActionMode,
pub mkdir: bool,
pub excluded_files: Vec<Regex>,
pub included_files: Vec<Regex>,
}Expand description
AnalyzerSettings is a struct that holds the settings for an Analyzer.
Fields
analysis_type- AnAnalysisTypethat specifies the type of analysis to perform on a file.exif_date_type- Which EXIF date to use when analyzing photos. SeeExifDateTypefor details.source_dirs- A vector ofPathreferences that represent the source directories to analyze.target_dir- APathreference that represents the target directory for the analysis results.recursive_source- A boolean that indicates whether to analyze source directories recursively.file_format- A string that represents the target format of the files to analyze.nodate_file_format- A string that represent the target format of files with no date.unknown_file_format- An optional string that represents the target format of files not matching the list of extensionsdate_format- A string that represents the format of the dates in the files to analyze.extensions- A vector of strings that represent the file extensions to consider during analysis.action_type- AnActionModethat specifies the type of action to perform on a file after analysis.mkdir- A boolean that indicates whether to create the target directory if it does not exist.excluded_files- A list of regexes to check if a file should be excluded from analysis.included_files- A list of regexes to check if a file should be included in the analysis. If this list is not empty, only files matching at least one of the regexes will be included.bracketed_file_format- Which data to select for formatting for non leaf path when the file is part of a bracketed set.
Fields
analysis_type: AnalysisTypeexif_date_type: ExifDateTypesource_dirs: Vec<PathBuf>target_dir: PathBufrecursive_source: boolfile_format: Stringnodate_file_format: Stringunknown_file_format: Option<String>bracketed_file_format: Option<String>date_format: Stringbracketing_formatting: BracketingFormattingPriorityextensions: Vec<String>action_type: ActionModemkdir: boolexcluded_files: Vec<Regex>included_files: Vec<Regex>Trait Implementations
Sourceimpl Clone for AnalyzerSettings
impl Clone for AnalyzerSettings
Sourcefn clone(&self) -> AnalyzerSettings
fn clone(&self) -> AnalyzerSettings
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for AnalyzerSettings
impl RefUnwindSafe for AnalyzerSettings
impl Send for AnalyzerSettings
impl Sync for AnalyzerSettings
impl Unpin for AnalyzerSettings
impl UnsafeUnpin for AnalyzerSettings
impl UnwindSafe for AnalyzerSettings